@@ -1,6 +1,6 @@
 # This file is part of Mkat
 #
-# Copyright (C) 2005 Dmitry Maksyoma <ledestin at amur.ru>.
+# Copyright (C) 2005, 2013 Dmitry Maksyoma <ledestin at gmail.com>.
 #
 # Mkat is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,32 +17,64 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 # USA.
 
-#shellscript helper functions
+#This library provides shell helper functions,
 #including Ruby optparse-like option handling
 
 RET='
 '
 
+#load_config(config)
 function load_config {
   [ -f "$1" ] && . "$1" || return 1
   #eval variables
-  for v in DRIVE CD LISTDIR TMP ISOIMAGE; do
+  for v in DRIVE CD LISTDIR TMP ISO_IMAGE; do
     eval "val=\"\$$v\""; eval "$v=\"$val\""
   done
   return 0
 }
 
+#fail_unless_defined(var_names)
+function fail_unless_defined {
+  for v in $@; do
+    eval "[ -z \"\$$v\" ] && 
+      { error '"$v" variable must be defined (see mkatrc(5))'; exit 1; }"
+  done
+}
+
+#usage(exitcode) prints BANNERS, program OPTIONS
+#and exits with exitcode
+function usage {
+  local SCRIPT=`basename $0`
+  for b in "${BANNERS[@]}"; do
+    echo "usage: $SCRIPT $b"
+  done
+  print_usage
+  exit $1
+}
+
+#debug(msg)
 function debug {
   [ -z $DEBUG ] || echo "$@"
 }
 
+#error(msg)
 function error {
-  echo >&2 error: "$@"
+  echo >&2 ERROR: "$@"
 }
 
+function hint {
+  echo >&2 "Hint: $@"
+}
+
+#quit(msg, exitcode)
+function quit {
+  error $1; exit $2
+}
+
+#make_dir(dir)
 function make_dir {
-  if [ ! -d $1 ]; then
-    mkdir -p $1 >/dev/null 2>&1
+  if [ ! -d "$1" ]; then
+    mkdir -p "$1" >/dev/null 2>&1
     [ $? -eq 0 ] || exit 1
   fi
 }
@@ -87,8 +119,10 @@ function print_usage {
 }
 
 #process_options($*)
-#process a program's arguments, which means,
-#execute code attached to an option with eval
+#Process a program's arguments, which means,
+#execute code attached to an option with eval.
+#After the options with respectable arguments have been processed, the
+#non-option parameters are stored into the ARGUMENTS array.
 function process_options {
   local i=0 found REQUIRES_PARAM SHORT_OPTION cur_opt
   while [ ${#*} -gt 0 ]; do
@@ -107,12 +141,16 @@ function process_options {
     unset REQUIRES_PARAM; [ `expr index "$o" =` -ne 0 ] && REQUIRES_PARAM=1
     unset SHORT_OPTION; [ "_${1:0:2}" != '_--' ] && SHORT_OPTION=1
     #split short option to several short options if $o.len > 2, e.g. -vd
-    if [ $SHORT_OPTION ] && [ ${#1} -gt 2 ]; then
+    if [ $SHORT_OPTION ] && [ "_${o:0:2}" = "_${1:0:2}" ] && [ ${#1} -gt 2 ]; then
       cur_opt=$1; local j=2;
-      while [ ${#1} -gt $j ]; do
-	expd=(${expd[@]} -${1:$j:1})
-	let "j += 1"
-      done
+      if [ $REQUIRES_PARAM ]; then
+	expd[0]=${1:2}
+      else
+	while [ ${#1} -gt $j ]; do
+	  expd=(${expd[@]} -${1:$j:1})
+	  let "j += 1"
+	done
+      fi
       shift; set - ${cur_opt:0:2} ${expd[@]} "$@" 
     fi
     
@@ -130,11 +168,6 @@ function process_options {
     #process cur_opt
     if [ "${o%=*}" = "$1" ] || [ "--no${o}" = "$1" ]; then
       #debug "found argument: $1"
-      #make sure that $2 is a param if option requires one
-      if [ $REQUIRES_PARAM ]; then
-	([ "$2" ] && [ ${2:0:1} != '-' ]) || \
-	  { echo "option ${o//=/ } requires parameter"; exit 1; }
-      fi
       #execute action associated with the option
       local varname=''; local action=''
       for word in ${OPTIONS[$(($i+2))]}; do
